@@ -2,9 +2,9 @@
 //
 //  RQuantLib function BermudanSwaption
 //
-//  Copyright (C) 2005 - 2007 Dominick Samperi
-//  Copyright (C) 2007 - 2014 Dirk Eddelbuettel
-//  Copyright (C) 2016        Terry Leitch
+//  Copyright (C) 2005 - 2007  Dominick Samperi
+//  Copyright (C) 2007 - 2018  Dirk Eddelbuettel
+//  Copyright (C) 2016         Terry Leitch
 //
 //  This file is part of RQuantLib.
 //
@@ -21,11 +21,11 @@
 //  You should have received a copy of the GNU General Public License
 //  along with RQuantLib.  If not, see <http://www.gnu.org/licenses/>.
 
-#include "rquantlib.h"
+#include <rquantlib_internal.h>
 
 // Calibrates underlying swaptions to the input volatility matrix.
 void calibrateModel(const boost::shared_ptr<QuantLib::ShortRateModel>& model,
-                    const std::vector<boost::shared_ptr<QuantLib::CalibrationHelper> > &helpers,
+                    const std::vector<boost::shared_ptr<QuantLib::BlackCalibrationHelper> > &helpers,
                     QuantLib::Real lambda,
                     Rcpp::NumericVector &swaptionMat, 
                     Rcpp::NumericVector &swapLengths, 
@@ -84,8 +84,6 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
     // ActualActual::ISDA ensures that 30 years is 30.0
     QuantLib::DayCounter termStructureDayCounter = 
         QuantLib::ActualActual(QuantLib::ActualActual::ISDA);
-    double tolerance = 1.0e-15;
-
 
     boost::shared_ptr<QuantLib::Quote> flatRate(new QuantLib::SimpleQuote(yield[0]));  // FIXME: hardcoded?
     QuantLib::Handle<QuantLib::YieldTermStructure> 
@@ -166,21 +164,21 @@ Rcpp::List bermudanFromYieldEngine(Rcpp::List rparam,
         swaptionMaturities.push_back(QuantLib::Period(swaptionMat[i], QuantLib::Years));
 
     // Swaptions used for calibration
-    std::vector<boost::shared_ptr<QuantLib::CalibrationHelper> > swaptions;
+    std::vector<boost::shared_ptr<QuantLib::BlackCalibrationHelper> > swaptions;
 
     // List of times that have to be included in the timegrid
     std::list<QuantLib::Time> times;
     for (i=0; i<(QuantLib::Size)numRows; i++) {
         //boost::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols[i][numCols-i-1]));
         boost::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols(i, numCols-i-1)));
-        swaptions.push_back(boost::shared_ptr<QuantLib::CalibrationHelper>(new QuantLib::SwaptionHelper(swaptionMaturities[i],
-                                                                                                        QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
-                                                                                                        QuantLib::Handle<QuantLib::Quote>(vol),
-                                                                                                        indexSixMonths,
-                                                                                                        indexSixMonths->tenor(),
-                                                                                                        indexSixMonths->dayCounter(),
-                                                                                                        indexSixMonths->dayCounter(),
-                                                                                                        rhTermStructure)));
+        swaptions.push_back(boost::shared_ptr<QuantLib::BlackCalibrationHelper>(new QuantLib::SwaptionHelper(swaptionMaturities[i],
+                                                                                                             QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
+                                                                                                             QuantLib::Handle<QuantLib::Quote>(vol),
+                                                                                                             indexSixMonths,
+                                                                                                             indexSixMonths->tenor(),
+                                                                                                             indexSixMonths->dayCounter(),
+                                                                                                             indexSixMonths->dayCounter(),
+                                                                                                             rhTermStructure)));
         swaptions.back()->addTimesTo(times);
 
     }
@@ -392,7 +390,7 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
         swaptionMaturities.push_back(QuantLib::Period(swaptionMat[i], QuantLib::Years));
     
     // Swaptions used for calibration
-    std::vector<boost::shared_ptr<QuantLib::CalibrationHelper> > swaptions;
+    std::vector<boost::shared_ptr<QuantLib::BlackCalibrationHelper> > swaptions;
 
     // List of times that have to be included in the timegrid
     std::list<QuantLib::Time> times;
@@ -400,14 +398,14 @@ Rcpp::List bermudanWithRebuiltCurveEngine(Rcpp::List rparam,
 
         //boost::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols[i][numCols-i-1]));
         boost::shared_ptr<QuantLib::Quote> vol(new QuantLib::SimpleQuote(swaptionVols(i, numCols-i-1)));
-        swaptions.push_back(boost::shared_ptr<QuantLib::CalibrationHelper>(new QuantLib::SwaptionHelper(swaptionMaturities[i],
-                                                                                                        QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
-                                                                                                        QuantLib::Handle<QuantLib::Quote>(vol),
-                                                                                                        indexSixMonths,
-                                                                                                        indexSixMonths->tenor(),
-                                                                                                        indexSixMonths->dayCounter(),
-                                                                                                        indexSixMonths->dayCounter(),
-                                                                                                        rhTermStructure)));
+        swaptions.push_back(boost::shared_ptr<QuantLib::BlackCalibrationHelper>(new QuantLib::SwaptionHelper(swaptionMaturities[i],
+                                                                                                             QuantLib::Period(swapLengths[numCols-i-1], QuantLib::Years),
+                                                                                                             QuantLib::Handle<QuantLib::Quote>(vol),
+                                                                                                             indexSixMonths,
+                                                                                                             indexSixMonths->tenor(),
+                                                                                                             indexSixMonths->dayCounter(),
+                                                                                                             indexSixMonths->dayCounter(),
+                                                                                                             rhTermStructure)));
         swaptions.back()->addTimesTo(times);
     }
 
