@@ -2,11 +2,10 @@
 //
 //  RQuantLib -- R interface to the QuantLib libraries
 //
-//  Copyright (C) 2002 - 2015  Dirk Eddelbuettel 
+//  Copyright (C) 2002 - 2018  Dirk Eddelbuettel 
 //  Copyright (C) 2005 - 2006  Dominick Samperi
 //  Copyright (C) 2009 - 2012  Dirk Eddelbuettel and Khanh Nguyen
 //
-//
 //  RQuantLib is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation, either version 2 of the License, or
@@ -20,7 +19,7 @@
 //  You should have received a copy of the GNU General Public License
 //  along with RQuantLib.  If not, see <http://www.gnu.org/licenses/>.
 
-#include <rquantlib.h>
+#include <rquantlib_internal.h>
 
 // [[Rcpp::interfaces(r, cpp)]]
 
@@ -379,8 +378,10 @@ QuantLib::DayCounter getDayCounter(const double n){
         return QuantLib::SimpleDayCounter();
     else if (n==6)
         return QuantLib::Thirty360();
-    else if (n==7)
-        return QuantLib::Actual365NoLeap();
+#ifdef RQUANTLIB_USE_ACTUAL365NOLEAP
+     else if (n==7)
+         return QuantLib::Actual365NoLeap();
+#endif    
     else if (n==8)
         return QuantLib::ActualActual(QuantLib::ActualActual::ISMA);
     else if (n==9)
